@@ -177,7 +177,11 @@ impl Parameters {
             "nnef" => {
                 let nnef = super::nnef(&matches);
                 let proto_model = if location.is_dir() {
-                    nnef.proto_model_for_read(&mut *location.read()?)?
+                    if let ModelLocation::Fs(dir) = location {
+                        nnef.proto_model_for_path(dir)?
+                    } else {
+                        unreachable!();
+                    }
                 } else if location
                     .path()
                     .extension()
@@ -796,7 +800,9 @@ impl Parameters {
             .collect();
 
         let mut assertions = match matches.subcommand() {
-            Some(("dump" | "run", sm)) => Assertions::from_clap(&matches, &*output_names_and_labels)?,
+            Some(("dump" | "run", sm)) => {
+                Assertions::from_clap(&matches, &*output_names_and_labels)?
+            }
             _ => Assertions::default(),
         };
 
